@@ -34,6 +34,8 @@ sub mk_app {
     $self->_mk_dirs;
     $self->_mk_appclass;
     $self->_mk_makefile;
+    $self->_mk_readme;
+    $self->_mk_changes;
     $self->_mk_apptest;
     $self->_mk_server;
     $self->_mk_test;
@@ -168,8 +170,8 @@ sub next_test {
 sub _mk_dirs {
     my $self = shift;
     $self->mk_dir( $self->{dir} );
-    $self->{bin} = File::Spec->catdir( $self->{dir}, 'bin' );
-    $self->mk_dir( $self->{bin} );
+    $self->{script} = File::Spec->catdir( $self->{dir}, 'script' );
+    $self->mk_dir( $self->{script} );
     $self->{lib} = File::Spec->catdir( $self->{dir}, 'lib' );
     $self->mk_dir( $self->{lib} );
     $self->{root} = File::Spec->catdir( $self->{dir}, 'root' );
@@ -258,6 +260,27 @@ WriteMakefile(
 EOF
 }
 
+sub _mk_readme {
+    my $self = shift;
+    my $dir  = $self->{dir};
+    $self->mk_file( "$dir\/README", <<"EOF");
+Run script/server.pl to test the application.
+EOF
+}
+
+sub _mk_changes {
+    my $self = shift;
+    my $name = $self->{name};
+    my $dir  = $self->{dir};
+    my $time = localtime time;
+    $self->mk_file( "$dir\/Changes", <<"EOF");
+This file documents the revision history for Perl extension $name.
+
+0.01  $time
+        - initial revision, generated by Catalyst
+EOF
+}
+
 sub _mk_apptest {
     my $self = shift;
     my $t    = $self->{t};
@@ -280,10 +303,10 @@ EOF
 }
 
 sub _mk_server {
-    my $self = shift;
-    my $name = $self->{name};
-    my $bin  = $self->{bin};
-    $self->mk_file( "$bin\/server", <<"EOF");
+    my $self   = shift;
+    my $name   = $self->{name};
+    my $script = $self->{script};
+    $self->mk_file( "$script\/server.pl", <<"EOF");
 #!/usr/bin/perl -w
 
 use strict;
@@ -311,7 +334,7 @@ server - Catalyst Testserver
 
 =head1 SYNOPSIS
 
-server [options]
+server.pl [options]
 
  Options:
    -? -help    display this help and exits
@@ -338,14 +361,14 @@ the same terms as perl itself.
 
 =cut
 EOF
-    chmod 0700, "$bin/server";
+    chmod 0700, "$script/server.pl";
 }
 
 sub _mk_test {
-    my $self = shift;
-    my $name = $self->{name};
-    my $bin  = $self->{bin};
-    $self->mk_file( "$bin/test", <<"EOF");
+    my $self   = shift;
+    my $name   = $self->{name};
+    my $script = $self->{script};
+    $self->mk_file( "$script/test.pl", <<"EOF");
 #!/usr/bin/perl -w
 
 use strict;
@@ -374,14 +397,14 @@ test - Catalyst Test
 
 =head1 SYNOPSIS
 
-test [options] uri
+test.pl [options] uri
 
  Options:
    -help    display this help and exits
 
  Examples:
-   perl test http://localhost/some_action
-   perl test /some_action
+   test.pl http://localhost/some_action
+   test.pl /some_action
 
  See also:
    perldoc Catalyst::Manual
@@ -404,14 +427,14 @@ the same terms as perl itself.
 
 =cut
 EOF
-    chmod 0700, "$bin/test";
+    chmod 0700, "$script/test.pl";
 }
 
 sub _mk_create {
-    my $self = shift;
-    my $name = $self->{name};
-    my $bin  = $self->{bin};
-    $self->mk_file( "$bin\/create", <<"EOF");
+    my $self   = shift;
+    my $name   = $self->{name};
+    my $script = $self->{script};
+    $self->mk_file( "$script\/create.pl", <<"EOF");
 #!/usr/bin/perl -w
 
 use strict;
@@ -437,19 +460,19 @@ create - Create a new Catalyst Component
 
 =head1 SYNOPSIS
 
-create [options] model|view|controller name [helper] [options]
+create.pl [options] model|view|controller name [helper] [options]
 
  Options:
    -help    display this help and exits
 
  Examples:
-   perl create controller My::Controller
-   perl create view My::View
-   perl create view MyView TT
-   perl create view TT TT
-   perl create model My::Model
-   perl create model SomeDB CDBI dbi:SQLite:/tmp/my.db
-   perl create model AnotherDB CDBI dbi:Pg:dbname=foo root 4321
+   create.pl controller My::Controller
+   create.pl view My::View
+   create.pl view MyView TT
+   create.pl view TT TT
+   create.pl model My::Model
+   create.pl model SomeDB CDBI dbi:SQLite:/tmp/my.db
+   create.pl model AnotherDB CDBI dbi:Pg:dbname=foo root 4321
 
  See also:
    perldoc Catalyst::Manual
@@ -472,7 +495,7 @@ the same terms as perl itself.
 
 =cut
 EOF
-    chmod 0700, "$bin/create";
+    chmod 0700, "$script/create.pl";
 }
 
 sub _mk_compclass {
